@@ -3,8 +3,9 @@ from social_distancing_sim.agent.basic_agents.isolation_agent import IsolationAg
 from social_distancing_sim.agent.basic_agents.vaccination_agent import VaccinationAgent
 from social_distancing_sim.agent.basic_agents.masking_agent import MaskingAgent
 from social_distancing_sim.agent.basic_agents.dummy_agent import DummyAgent
+from social_distancing_sim.agent.basic_agents.treatment_agent import TreatmentAgent
 from social_distancing_sim.agent.policy_agents.distancing_policy_agent import DistancingPolicyAgent
 from social_distancing_sim.agent.policy_agents.vaccination_policy_agent import VaccinationPolicyAgent
 from social_distancing_sim.agent.policy_agents.treatment_policy_agent import TreatmentPolicyAgent
 from social_distancing_sim.agent.policy_agents.masking_policy_agent import MaskingPolicyAgent
-from social_distancing_sim.agent.multi_agent.multi_agent import MultiAgent
+from social_distancing_sim.agent.multi_agents.multi_agent import MultiAgent
