@@ -1,10 +1,9 @@
 from typing import List, Dict
 
-from social_distancing_sim.agent.agent_base import AgentBase
-from social_distancing_sim.environment.observation_space import ObservationSpace
+from social_distancing_sim.agent.non_learning_agent_base import NonLearningAgentBase
 
 
-class IsolationAgent(AgentBase):
+class IsolationAgent(NonLearningAgentBase):
     """Isolation agent will either isolate known infected, connected nodes, or reconnect known clear, isolated nodes."""
     @property
     def available_actions(self) -> List[int]:
@@ -12,10 +11,10 @@ class IsolationAgent(AgentBase):
 
     @property
     def available_targets(self) -> Dict[int, List[int]]:
-        return {2: list(set(self.env.observation_space.current_infected_nodes).difference
-                        (self.env.observation_space.current_isolated_nodes)),
-                3: list(set(self.env.observation_space.current_clear_nodes).intersection(
-                    self.env.observation_space.current_isolated_nodes))}
+        return {2: list(set(self.env.sds_env.observation_space.current_infected_nodes).difference
+                        (self.env.sds_env.observation_space.current_isolated_nodes)),
+                3: list(set(self.env.sds_env.observation_space.current_clear_nodes).intersection(
+                    self.env.sds_env.observation_space.current_isolated_nodes))}
 
     def _select_actions_targets(self) -> Dict[int, str]:
         """Selects randomly between both actions, any time frames are totally ignored."""
