@@ -1,20 +1,19 @@
 from typing import List, Dict
 
-from social_distancing_sim.agent.agent_base import AgentBase
+from social_distancing_sim.agent.non_learning_agent_base import NonLearningAgentBase
 
 
-class VaccinationAgent(AgentBase):
+class VaccinationAgent(NonLearningAgentBase):
     """VaccinationAgent randomly vaccinates clear nodes."""
 
     @property
     def available_actions(self) -> List[int]:
-        """Isolation agent can only isolate. It can't even un-isolate (yet?)"""
         return [1]
 
     @property
     def available_targets(self) -> List[int]:
-        return list(set(self.env.observation_space.current_clear_nodes).difference(
-            self.env.observation_space.current_immune_nodes))
+        return list(set(self.env.sds_env.observation_space.current_clear_nodes).difference(
+            self.env.sds_env.observation_space.current_immune_nodes))
 
     def _select_actions_targets(self) -> Dict[int, int]:
         # Don't track sample call here as self.get_actions() will handle that.
